/*
X302Demo.c: Demo program for X302

Compiler: BC++ 3.1
          Turbo C ++ 1.01(3.01) (free from http://community.borland.com/museum)

Compile mode: large

Project: X301Demo.c
         ..\..\lib\7188xcl.lib
         ..\..\lib\XBoard\X302.lib
         
Hardware: 7188XC + X302

[June/20/2002] by David
[May/19/2005] by Liam
[08/July/2005] by Liam

/********************************************************************/
/*  X302:   1 channel 12-Bit A/D (Analog input)  +/-5.0V            */
/*          1 channel 12-Bit D/A (Analog output) +/-5.0V            */
/********************************************************************/

/********************************************************************/
/*  [Software specific]                                             */
/*      Input/Output range: -5.0V     -0.0V     +0.0V   +5.0V       */
/*      Decimal integer:    0         2047      2048    4095        */
/*      Hexadecimal:        000       7FF       800     FFF         */
/*                                                                  */
/*      [A/D]                                                       */
/*      sampling rate:  1800 data/sec (with floating convertion)    */
/*      Accuracy==>     Typical: +- 1 LSB (+- 2.4 mV)               */
/*                      Maximum: +- 2 LSB (+- 4.8 mV)               */
/*      [D/A]                                                       */
/*      thoughput :     1300 data/sec (with floating convertion)    */
/*      Accuracy==>     Typical: +- 1 LSB (+- 2.4 mV)               */
/*                      Maximum: +- 2 LSB (+- 4.8 mV)               */
/*      [D/O]                                                       */
/*      throughput:     can generates 2KHz square wave signals.     */
/********************************************************************/

/********************************************************************/
/*  [Caution]                                                       */
/*      The block 7 first 16 bytes of EEPROM on X board is used to  */
/*      store A/D & D/A calibration settings. When you use the      */
/*      EEPROM on X board, don't overwrite it.                      */
/********************************************************************/

#include <stdio.h>
#include "..\..\lib\7188xc.h"
#include "..\..\lib\XBoard\X302.h"

void main(void)
{
    int iAction, iChannel, iValue, quit;
    float fValue;
    
    InitLib();
    X302_Init();    //Initialize the X302
    
    Puts("\r\nDemo program for 7188XC + X302\r\n");
    
    while(iAction!=4)
    {
        quit=0;
        iAction=0;
        
        Puts("\r\n");
        Puts("1)Reads setting from EEPROM\r\n");
        Puts("2)A/D (Analog input)\r\n");
        Puts("3)D/A (Analog output)\r\n");
        Puts("\r\n");
        Puts("4)Quits demo program\r\n\r\n");
        Puts("Please select (1~4):");
        Scanf("%d", &iAction);
        Puts("\r\n");
        
        switch(iAction)
        {
            /******************************************/
            /* Reads settings from EEPROM(on X board) */
            /******************************************/
            case 1:
                iValue=X302_Init();
                if((iValue&1)==0)
                    Print("EEPROM A/D Gain ==> [%8.6f]\n\r", X302_fAD_Gain); 
                else
                    Print("No setting in EEPROM, A/D Gain ==> %8.6f\n\r", X302_fAD_Gain);
                
                if((iValue&2)==0)
                    Print("EEPROM A/D Offset ==> [%8.6f]\n\r", X302_fAD_Offset);
                else
                    Print("No setting in EEPROM, A/D Offset ==> %8.6f\n\r", X302_fAD_Offset);
                
                if((iValue&4)==0)
                    Print("EEPROM D/A Gain ==> [%8.6f]\n\r", X302_fDA_Gain);
                else
                    Print("No setting in EEPROM, D/A Gain ==> %8.6f\n\r", X302_fDA_Gain);

                if((iValue&8)==0)
                    Print("EEPROM D/A Offset ==> [%8.6f]\n\r", X302_fDA_Offset);
                else
                    Print("No setting in EEPROM, D/A Offset ==> %8.6f\n\r", X302_fDA_Offset);
                    
                Puts("\r\n");
            break;
            /**********************/
            /* A/D (Analog input) */
            /**********************/
            case 2:
                fValue=X302_AnalogIn();
                Print("AI[0]= %6.4fV\r\n\r\n", fValue);
            break;
            /***********************/
            /* D/A (Analog output) */
            /***********************/
            case 3:
                Puts("Voltage (-5.0 ~ +5.0): "); Scanf("%f", &fValue);
                X302_AnalogOut(fValue);
                Print("AO[0]  %5.3fV OK.\r\n\r\n", fValue);
            break;
            
            case 4:
            default:
                quit=1;
            break;
        }
        if(!quit)
        {
            Puts("Press any key to continue...\r\n");
            Getch();
        }
    }
}

